# easycalculate

A package for calculate Math problem contain easy calculation and easy linear algebra problem, in the future author will add functions to solve easy geometry problems.

- Written by JinXinxi
- Written with Python
- Latest Version: 2024-1-25 0.1.0

Brief overview:

- Sum(): Sum function
- Subtract(): Subtract function
- Multiply(): quadrature function
- Divide(): a quotient function that gives a judgment on whether to divide by integers, 0: not divide by integers; 1: Dividing by whole
- Sqare(): Find the root of the power, the y-th power of x
- Square_ Root(): Open root function
- Invert(): Find the inverse ordinal number
- Determinant(): Find the value of the number of rows and columns
- Cofactor(): finding algebraic cofactors
- ......